Support for AnyWidgets
Public fields
_model_moduleName of the Javascript module with the model
_model_module_versionVersion of the module where the model is defined
_model_nameName of the Javascript model in the frontend
_view_nameName of the Javascript model view in the frontend
_view_moduleName of the module where the view is defined
_view_module_versionVersion of the module where the view is defined
_anywidget_idA Unicode trait
_cssA Unicode trait with optional CSS code
_esmA Unicode trait with optional Javascript code
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$initialize()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()