Skip to contents

An R6 class and a constructor function for the creation of widgets that can be used to manipulate floating pairs of point numbers that are bounded within an interval, where a pair defines a number range.

Usage

BoundedFloatRangeWidget(value, min, max, ...)

Arguments

value

A pair of floating point values.

min

The lower bound of the enclosing interval.

max

The upper bound of the enclosing interval.

...

Other arguments, passed to the superclass initializer.

Details

The function BoundedFloatRangeWidget creates objects of the R6 Class "BoundedFloatRangeWidgetClass", which in turn have the S3 class attribute "BoundedFloatRangeWidget"

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> BoundedFloatRangeWidget

Public fields

value

A Float traitlet.

min

A Float traitlet, the minimum allowed value.

max

A Float traitlet, the maximum allowed value.

Methods

Inherited methods


BoundedFloatRangeWidget$validate_value()

Validate the "value" after assignment.

Usage

BoundedFloatRangeWidget$validate_value(value)

Arguments

value

A value, should be numeric.


BoundedFloatRangeWidget$validate_min()

Validate the "min" field after assignment.

Usage

BoundedFloatRangeWidget$validate_min(min)

Arguments

min

A minimum value, should be numeric.


BoundedFloatRangeWidget$validate_max()

Validate the "max" field after assignment.

Usage

BoundedFloatRangeWidget$validate_max(max)

Arguments

max

A maximum value, should be numeric.


BoundedFloatRangeWidget$new()

Usage

Arguments

...

Arguments passed to the superclass initializer.


BoundedFloatRangeWidget$clone()

The objects of this class are cloneable with this method.

Usage

BoundedFloatRangeWidget$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.