Skip to contents

An R6 class and a constructor function for the creation of widgets that can be used to manipulate floating point numbers that are bounded within an interval on an logarithmic scale

Usage

BoundedLogFloatWidget(value, min, max, base, ...)

Arguments

value

The floating point value.

min

The lower bound of the interval.

max

The upper bound of the interval.

base

The base of the logarithm.

...

Other arguments, passed to the superclass initializer.

Details

The function BoundedLogFloatWidget creates objects of the R6 Class "BoundedLogFloatWidgetClass", which in turn have the S3 class attribute "BoundedLogFloatWidget"

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> BoundedLogFloatWidget

Public fields

value

A Float traitlet.

min

A Float traitlet, the minimum allowed value.

max

A Float traitlet, the maximum allowed value.

base

A Float traitlet, the logarithmic base.

Methods

Inherited methods


BoundedLogFloatWidget$validate_value()

Validate the "value" after assignment.

Usage

BoundedLogFloatWidget$validate_value(value)

Arguments

value

A value, should be numeric.


BoundedLogFloatWidget$validate_min()

Validate the "min" field after assignment.

Usage

BoundedLogFloatWidget$validate_min(min)

Arguments

min

A minimum value, should be numeric.


BoundedLogFloatWidget$validate_max()

Validate the "max" field after assignment.

Usage

BoundedLogFloatWidget$validate_max(max)

Arguments

max

A maximum value, should be numeric.


BoundedLogFloatWidget$new()

Initialize an object.

Usage

BoundedLogFloatWidget$new(value, min, max, ...)

Arguments

value

The floating point value.

min

The lower bound of the interval.

max

The upper bound of the interval.

...

Other arguments, passed to the superclass initializer.


BoundedLogFloatWidget$clone()

The objects of this class are cloneable with this method.

Usage

BoundedLogFloatWidget$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.