Classes and constructor functions to create box container widgets
Usage
Box(..., layout = NULL)
HBox(..., layout = NULL, wrap = FALSE)
VBox(..., layout = NULL, wrap = FALSE)
GridBox(..., layout = NULL)Details
VBox creates vertical boxes, HBox creates horizontal boxes,
GridBox creates a grid box. In a vertical box widgets are arranged one below the other,
in a horizontal box widgets are arranged side-by-side, in a grid box widget are arraned in a
grid.
Functions
Box(): A baseline box constructorHBox(): A horizontal box constructorVBox(): A vertical box constructorGridBox(): A grid box constructor
Public fields
_model_moduleName of the Javascript module with the model
_model_module_versionVersion of the module where the model is defined
_model_nameName of the Javascript model in the frontend
_view_nameName of the Javascript model view in the frontend
_view_moduleName of the module where the view is defined
_view_module_versionVersion of the module where the view is defined
childrenA generic vector with the widgets in the container
box_styleThe string that describes the button style
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()
Public fields
_model_nameName of the Javascript model in the frontend
_view_nameName of the Javascript model view in the frontend
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$initialize()Box$notify_children_displayed()
Public fields
_model_nameName of the Javascript model in the frontend
_view_nameName of the Javascript model view in the frontend
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$initialize()Box$notify_children_displayed()
Public fields
_model_nameName of the Javascript model in the frontend
_view_nameName of the Javascript model view in the frontend
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$initialize()Box$notify_children_displayed()