Classes and constructor functions for boxes and box styles
Public fields
_model_moduleName of the Javascript module with the model
_model_module_versionVersion of the module where the model is defined
_model_nameName of the Javascript model in the frontend
_view_moduleName of the module where the view is defined
_view_module_versionVersion of the module where the view is defined
_view_nameName of the Javascript model view in the frontend
descriptionA button description
disabledBoolean, whether the button is disabled
iconName of an optional icon
button_styleThe string that describes the button style
tooltipAn optional tooltip string
styleThe button style, an object of class "ButtonStyleClass"
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$initialize()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()
Super classes
HasTraits -> Widget -> DescriptionStyle -> ButtonStyle
Public fields
_model_nameName of the Javascript model in the frontend
button_colorThe colour of the button
font_familyThe font family of the button label
font_sizeThe font size of the button label
font_styleThe font style of the button label
font_variantThe font variant of the button label
font_weightThe font weight of the button label
text_colorThe text colour of the button label
text_decorationThe text decoration of the button label
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$initialize()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()