Skip to contents

A class and constructor function to create color picker widgets

Usage

ColorPicker(...)

Arguments

...

Arguments passed to the inializer

Functions

  • ColorPicker(): The constructor for color-picker widgets

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> ColorPicker

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript model view in the frontend

concise

Boolean, whether the a short version should be shown

disabled

Boolean, whether the button is disabled

value

Unicode string, the color value