This is a base class for all widgets that are supposed to be part of the document object model
Public fields
_model_moduleName of the Javascript module with the model
_model_module_versionVersion of the module where the model is defined
_model_nameName of the Javascript model in the frontend
_dom_classesA set of character strings that indicate the DOM classes the widget is assigned to
layoutThe layout, a "LayoutClass" Widget
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$initialize()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()