Objects of this class have an optional description and a description tooltip field
Public fields
_model_moduleName of the Javascript module with the model
_model_module_versionVersion of the module where the model is defined
_view_moduleVersion of the module where the view is defined
_view_module_versionVersion of the module where the view is defined
_model_nameName of the Javascript model in the frontend
descriptionAn optional description string
description_tooltipAn optional description tooltip
tooltipAn optional description tooltip
description_htmlBoolean, whether HTML is allowed in the description
styleA "DescriptionStyle" object
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$initialize()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()