A class and a constructor of dictionary trait(let)s.
These are lists with unique element names.
Arguments
- ...
Arguments that are passed to the initialize method of 'DictClass'
Methods
Inherited methods
Dict$validator()
A function that checks the validity of an assigned value,
i.e. whether the assigned value is a list with unique names
Arguments
value
A value to be assigned as the traitlet value
Dict$clone()
The objects of this class are cloneable with this method.
Arguments
deep
Whether to make a deep clone.