A class and a constructor function to create floating point vector trait(let)s.
Usage
Float(...)
# S3 method for class 'Float'
as.integer(x, ...)
# S3 method for class 'Float'
as.numeric(x, ...)Super class
Trait -> Float
Public fields
valueA numeric vector.
optionalLogical value, whether a length-zero value is allowed.
coerceLogical value, whether assignments to the value field should be coerced to the appropriate type.
lengthInteger number, the length the value should have.
Methods
Inherited methods
Float$new()
Initialize the traitlet.
Arguments
initialA numeric vector, the initial value for the traitlet.
coercecoerce Logical value, whether assignments to the value field should be coerced to the appropriate type.
optionalLogical value, whether a length-zero value is allowed.
lengthInteger number, the length the value should have.