An R6 class and a constructor function for the creation of
a layout widget, which itself is used to manipulate the layout of
a DOMWidget.
Details
The function Layout creates objects of the R6 Class
"LayoutClass", which in turn have the S3 class attribute "Layout"
Public fields
_view_nameName of the Javascript view in the frontend.
_view_moduleName of the Javascript view module in the frontend.
_view_module_versionVersion of the Javascript view module in the frontend.
_model_nameName of the Javascript model in the frontend.
align_contentAn optional string, if non-empty, one of "flex-start", "flex-end", "center", "space-between", "space-around", "space-evenly", "stretch"
align_itemsAn optional string, if non-empty, one of "flex-start", "flex-end", "center", "baseline", "stretch"
align_selfAn optional string, if non-empty, one of "flex-start", "flex-end", "center", "baseline", "stretch"
bottomPosition from bottom, an optional string that should, if non-empty, contain a valid CSS dimension
borderAn optional string with a valid CSS border specification
border_topAn optional string with a valid CSS border specification
border_rightAn optional string with a valid CSS border specification
border_bottomAn optional string with a valid CSS border specification
border_leftAn optional string with a valid CSS border specification
displayAn optional string with a valid CSS display property
flexAn optional string with a valid CSS flex property
flex_flowAn optional string with a valid CSS flex_flow property
heightAn optional string with a valid CSS height
justify_contentAn optional string, if non-empty, one of "flex-start", "flex-end", "center", "space-between", "space-around".
justify_itemsAn optional string, if non-empty, one of "flex-start", "flex-end", or "center"
leftPosition from left, an optional string that should, if non-empty, contain a valid CSS dimension
marginAn optional string, if non-empty, should be a valid CSS margin specification
max_heightAn optional string, if non-emtpy, should be a valid CSS dimension
max_widthAn optional string, if non-emtpy, should be a valid CSS dimension
min_heightAn optional string, if non-emtpy, should be a valid CSS dimension
min_widthAn optional string, if non-emtpy, should be a valid CSS dimension
overflowAn optonal string, if non-empty, should be a valid CSS overflow specification
orderAn optional string, if non-empty should contain a number
paddingAn optional string, if non-emtpy should be a valid CSS dimension
rightPosition from right, an optional string, if non-empty, should be a valid CSS dimension
topPosition from top, an optional string, if non-empty, should be a valid CSS dimension
visibilityAn optional string, if non-empty, should be either "visible" or "hidden"
widthAn optional string, if non-empty, should be a valid CSS dimension
object_fitAn optional string, if non-empty, should be one of "contain", "cover", "fill", "scale-down", "none"
object_positionAn optional string, if non-empty, should be a valid CSS object-position specification
grid_auto_columnsAn optional string, if non-empty should be valid CSS code for the grid-auto-columns property
grid_auto_flowAn optional string, if non-empty should be valid CSS code for the grid-auto-flow property
grid_auto_rowsAn optional string, if non-empty should be valid CSS code for the grid-auto-rows property
grid_gapAn optional string, if non-empty should be valid CSS code for the grid-gap property
grid_template_rowsAn optional string, if non-empty should be valid CSS code for the grid-template-rows property
grid_template_columnsAn optional string, if non-empty should be valid CSS code for the grid-template-columns property
grid_template_areasAn optional string, if non-empty should be valid CSS code for the grid-template-areas property
grid_rowAn optional string, if non-empty should be valid CSS code for the grid-row property
grid_columnAn optional string, if non-empty should be valid CSS code for the grid-column property
grid_areaAn optional string, if non-empty should be valid CSS code for the grid-area property
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()