R6 classes and constructor functions for widget layout templates
Usage
AppLayout(...)
GridspecLayout(...)
# S3 method for class 'GridspecLayout'
x[i, j, ..., drop = TRUE]
# S3 method for class 'GridspecLayout'
x[i, j] <- value
TwoByTwoLayout(...)Arguments
- ...
Arguments used to initialize the fields
- x
A GridspecLayout object
- i
Integer value(s) referring to the row(s)
- j
Integer value(s) referring to the column(s)
- drop
Logical, whether the result is a widget or a list with one element if both i an j select a single element
- value
One or more widgets put at the idicated positions in the grid
Public fields
grid_gapThe grid-gap CSS attribute
justify_contentThe justify-content CSS attribute
align_itemsThe align-items CSS attribute
widthThe width CSS attribute
heightThe height CSS attribute
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$notify_children_displayed()
Public fields
headerWidget that appears in the header section
footerWidget that appears in the footer section
left_sidebarWidget that appears as left sidebar
right_sidebarWidget that appears as right sidebar
centerWidget that appears in the center section
pane_widthsUnicode string with CSS widths for the app panes
pane_heightsUnicode string with CSS heights for the app panes
mergeBoolean, whether space of missing widgets chould be merged
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$notify_children_displayed()
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$notify_children_displayed()
Public fields
top_leftWidget that appears on the top left
top_rightWidget that appears on the top right
bottom_leftWidget that appears on the bottom left
bottom_rightWidget that appears on the bottom right
mergeBoolean, whether space of missing widgets chould be merged
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$notify_children_displayed()