Skip to contents

A class and a constructor function to create list trait(let)s.

Usage

List(...)

Arguments

...

Arguments that are passed to the initialize method of 'ListClass'

Super class

Trait -> List

Public fields

value

A list

Methods

Inherited methods


List$validator()

A function that checks the validity of an assigned value, i.e. whether the assigned value is a list

Usage

List$validator(value)

Arguments

value

A value to be assigned as the traitlet value


List$clone()

The objects of this class are cloneable with this method.

Usage

List$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.