An R6 class and a constructor function for the creation of a player widget, which automatically increases its value-
Arguments
- value
Integer, an initial value.
- min
Integer, the minimum value.
- max
Integer, the maximum value.
- interval
Integer, the maximum value of the intrval .
- step
The maximum value for the play control.
- show_repeat
Logical, whether to show a repeat toggle button.
- ...
Further arguments, passed to the superclass constructor.
Super classes
HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> BoundedIntWidget -> Play
Public fields
_model_nameName of the Javascript model in the frontend
_view_nameName of the Javascript model view in the frontend
intervalAn Integer traitlet, the time interval between between two steps.
stepAn Integer traitlet, the step size.
_playingA Boolean traitlet, indicates wether the player widget is running.
playingA Boolean traitlet, indicates wether the player widget is running.
_repeatA Boolean traitlet, indicates wether the the repeat toggle is on.
repeatA Boolean traitlet, indicates wether the the repeat toggle is on.
show_repeatA Boolean traitlet, determines whether to show a repeat toggle button.
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()ValueWidget$on_change()BoundedIntWidget$initialize()BoundedIntWidget$validate_max()BoundedIntWidget$validate_min()BoundedIntWidget$validate_value()