Skip to contents

Class and constructors show graphics created by code

Usage

SVGWidget(...)

# S3 method for class 'SVGWidget'
with(data, expr, envir = list(), enclos = parent.frame(), ...)

PlotWidget(...)

Arguments

...

Arguments, passed to the ImageWidget constructors.

data

An "SVGWidget" object

expr

An expression to evaluate, or a sequence of expression, encapsulated by curly braces.

envir

An environment or a list within which `expr` is evaluated.

enclos

An enclosing environment.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget -> HTML -> SVGWidget

Methods

Inherited methods


SVGWidget$new()

Initialize the object

Usage

SVGWidget$new(..., width = NULL, height = NULL)

Arguments

...

Arguments passed to the superclass initializer

width

A character string, giving the width as a CSS property

height

A character string, giving the height as a CSS property


SVGWidget$activate()

Activate widget as graphics device

Usage

SVGWidget$activate()


SVGWidget$suspend()

Suspend widget as graphics device

Usage

SVGWidget$suspend()


SVGWidget$render()

Render contents of graphics device as SVG

Usage

SVGWidget$render()


SVGWidget$clone()

The objects of this class are cloneable with this method.

Usage

SVGWidget$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.