Skip to contents

An object of this class handles the communication with an R process. There is usually one main session, but there may also sessions for detached code cells.

Super classes

processx::process -> callr::r_session -> RSessionBase -> RKernelSession

Public fields

http_port

The port number of HTML help.

hostname

The hostname.

yield

An optional function to service kernel requests

kernel

The reference to the controlling kernel object

Methods

Inherited methods


RKernelSession$connect()

Connect the session with the main Kernel object

Usage

RKernelSession$connect(yield, kernel)

Arguments

yield

The function that is called when the session objects yields back control to the kernel object, for example in order to wait for comm message when a widget is active.

kernel

The main kernel objectd


RKernelSession$setup()

Set up the R session, by installing hooks etc.

Usage

RKernelSession$setup()


RKernelSession$start_graphics()

Initialize graphics, start device and return details

Usage

RKernelSession$start_graphics()


RKernelSession$dev_new()

Start a httpgd device and return the graphics details.

Usage

RKernelSession$dev_new()


RKernelSession$graphics_details()

Return the graphics details.

Usage

RKernelSession$graphics_details()


RKernelSession$http_get()

Usage

RKernelSession$http_get(slug = "", query = "")


RKernelSession$clone()

The objects of this class are cloneable with this method.

Usage

RKernelSession$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.