Skip to contents

Classes and constructor functions for tab and accordion widgets

Usage

Accordion(...)

Tab(...)

Stack(...)

Arguments

...

Arguments passed to the superclass constructor

Functions

  • Accordion(): The constructor function for accordion widgets.

  • Tab(): The construction function for accordion widgets.

  • Stack(): The construction function for accordion widgets.

Super classes

HasTraits -> Widget -> DOMWidget -> Box -> Box

Public fields

_titles

A dictionary of strings, for internal use only

titles

A dictionary of strings, exposed since ipywidgets 8.

selected_index

An integer, the field currently selected.

Methods

Inherited methods


Box$validate_index()

Validate the index, i.e. check whether it is within range.

Usage

Box$validate_index(index)

Arguments

index

An integer number.


Box$set_title()

Set the title of one of the elements.

Usage

Box$set_title(index, title)

Arguments

index

The index number of the element to be changed.

title

A character string, the intended title.


Box$get_title()

Get the title of one of the elements.

Usage

Box$get_title(index)

Arguments

index

The index number of the element to be enquired.


Box$new()

An initializer function

Usage

Box$new(children = list(), ...)

Arguments

children

A list of widgets

...

Other arguments, passed to the superclass method


Box$clone()

The objects of this class are cloneable with this method.

Usage

Box$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

HasTraits -> Widget -> DOMWidget -> Box -> Accordion

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

Super classes

HasTraits -> Widget -> DOMWidget -> Box -> Tab

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

Super classes

HasTraits -> Widget -> DOMWidget -> Box -> Stack

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

required_version

Minimum required ipywidgets version in which the current widget class is supported.