Skip to contents

Classes and constructors for selection widgets, i.e. dropdowns, listboxes etc.

Usage

SelectionWidget(options, value, ...)

Dropdown(options, value, ...)

RadioButtons(options, value, ...)

ListBox(options, value, ...)

ToggleButtons(options, value, ...)

SelectionSlider(options, value, ...)

MultipleSelectionWidget(options, value, ...)

ListBoxMultiple(options, value, ...)

SelectionRangeSlider(options, value, ...)

Arguments

options

A named vector or a vector coerceable into a character vector.

value

A trait.

...

Any other arguments, ignored.

Functions

  • SelectionWidget(): A constructor function for selection widgets.

  • Dropdown(): The construction function for dropdown widgets.

  • RadioButtons(): The construction function for radiobuttons widgets.

  • ListBox(): The construction function for listbox-selection widgets.

  • ToggleButtons(): The construction function for togglebuttons widgets.

  • SelectionSlider(): The construction function for listbox widgets with multiple selections.

  • MultipleSelectionWidget(): The construction function for multiple-selection widgets.

  • ListBoxMultiple(): The construction function for listbox widgets with multiple selections.

  • SelectionRangeSlider(): The construction function for listbox widgets with multiple selections.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> SelectionWidget

Public fields

_options_labels

A unicode vector of option labels.

index

An integer that refers to currently selected item.

Active bindings

value

The selected option

Methods

Inherited methods


SelectionWidget$validate_index()

Validate an index argument.

Usage

SelectionWidget$validate_index(index)

Arguments

index

The index to be checked.


SelectionWidget$new()

Initialiser

Usage

SelectionWidget$new(options, value, ...)

Arguments

options

A named vector or a vector coerceable into a character vector.

value

Name of a selectable option.

...

Any other arguments, ignored.


SelectionWidget$clone()

The objects of this class are cloneable with this method.

Usage

SelectionWidget$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> SelectionWidget -> Dropdown

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> SelectionWidget -> RadioButtons

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> SelectionWidget -> ListboxSelect

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

rows

An integer, the number of rows.

Super classes

HasTraits -> Widget -> DescriptionStyle -> ToggleButtonsStyle

Public fields

_model_name

Name of the Javascript model in the frontend.

button_width

A unicode string, the width in CSS language

font_weight

A unicode string, the font weight in CSS language

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> SelectionWidget -> ToggleButtons

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

tooltips

A unicode vector with tooltips.

icons

A unicode vector with icon specs.

style

A TobbleButtonStyle widget

button_style

A character string, one of "primary", "success", "info", "warning", "danger", or the empty string.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> SelectionWidget -> SelectionSlider

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

orientation

A Unicode string, either "horizontal" or "vertical"

readout

A logical value, whether the value should be showns (read out)

continuous_update

A logical value, whether values should be updated as the slider is moved by the user

style

A SliderStyle widget

behavior

A string that describes the ddragging behavior.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> MultipleSelectionWidget

Public fields

_options_labels

A unicode string vector with labels

index

An integer vector of indices of currenlty selected elements.

Active bindings

value

The selected option

Methods

Inherited methods


MultipleSelectionWidget$validate_index()

Validate an index.

Usage

MultipleSelectionWidget$validate_index(index)

Arguments

index

An index, the index to be checked.


MultipleSelectionWidget$new()

Initialiser

Usage

MultipleSelectionWidget$new(options, value, ...)

Arguments

options

A named vector or a vector coerceable into a character vector.

value

Names of selectable options.

...

Any other arguments, ignored.


MultipleSelectionWidget$clone()

The objects of this class are cloneable with this method.

Usage

MultipleSelectionWidget$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> MultipleSelectionWidget -> ListboxSelectMultiple

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

rows

An integer, the number of rows.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> MultipleSelectionWidget -> SelectionRangeSlider

Public fields

_model_name

Name of the Javascript model in the frontend.

_view_name

Name of the Javascript view in the frontend.

orientation

A Unicode string, either "horizontal" or "vertical"

readout

A logical value, whether the value should be showns (read out)

continuous_update

A logical value, whether values should be updated as the slider is moved by the user

style

A SliderStyle widget

behavior

A string that describes the ddragging behavior.

Methods

Inherited methods


SelectionRangeSlider$validate_index()

Validate an index.

Usage

SelectionRangeSlider$validate_index(index)

Arguments

index

An index, the index to be checked.


SelectionRangeSlider$new()

Initialiser

Usage

SelectionRangeSlider$new(options, value, ...)

Arguments

options

A named vector or a vector coerceable into a character vector.

value

Names of selectable options.

...

Any other arguments, ignored.


SelectionRangeSlider$clone()

The objects of this class are cloneable with this method.

Usage

SelectionRangeSlider$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.