Sidecar widgets - works only with Jupyter Lab
Details
Note that these widget need the sidecar extension for Jupyter Lab. See https://github.com/jupyter-widgets/jupyterlab-sidecar
Super classes
HasTraits -> Widget -> DOMWidget -> OutputWidget -> Sidecar
Public fields
_model_nameName of the Javascript model in the frontend
_model_moduleName of the Javascript frontend module
_model_module_versionVersion of the Javascript frontend module
_view_nameName of the Javascript view in the frontend
_view_moduleName of the Javascript frontend view module
_view_module_versionVersion of the the Javascript view module
titleA unicode string, the title of the widget.
anchorA string that specifies where the widget s to appear: one of "split-right", "split-left", "split-top", "split-bottom", "tab-before", "tab-after", or "right".
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()OutputWidget$clear()OutputWidget$display()OutputWidget$handle_msg()OutputWidget$initialize()OutputWidget$stderr()OutputWidget$stdout()