Skip to contents

Classes and constructor functions for string-related widgets (text areas etc.)

Usage

LabelStyle(...)

TextStyle(...)

HTMLStyle(...)

HTMLMathStyle(...)

StringWidget(value = character(0), ...)

HTML(value = character(0), ...)

HTMLMath(value = character(0), ...)

Label(value = character(0), ...)

Textarea(value = character(0), ...)

TextWidget(value = character(0), ...)

PasswordWidget(value = character(0), ...)

Combobox(value = character(0), ...)

Arguments

...

Arguments passed to the inializer

value

A character vector

Functions

  • LabelStyle(): The constructor for Label styles

  • TextStyle(): The constructor for Text styles

  • HTMLStyle(): The constructor for HTML styles

  • HTMLMathStyle(): The constructor for HTMLMath styles

  • StringWidget(): A constructor for string widgets

  • HTML(): A constructor for HTML widgets

  • HTMLMath(): A constructor for HTML widgets with math

  • Label(): A constructor for label widgets

  • Textarea(): A constructor for text area widgets

  • TextWidget(): A constructor for text field widgets

  • PasswordWidget(): A constructor for password entry widgets

  • Combobox(): A constructor for combo boxes

Super classes

HasTraits -> Widget -> DescriptionStyle -> StringStyle

Public fields

_model_name

Name of the Javascript model in the frontend

background

The background color

font_size

The font size

text_color

The text color

required_version

Minimum required ipywidgets version in which the current widget class is supported.

Super classes

HasTraits -> Widget -> DescriptionStyle -> StringStyle -> LabelStyle

Public fields

_model_name

Name of the Javascript model in the frontend

font_family

The font family

font_style

The font style

font_variant

The font variant

font_weight

The font weight

text_decoration

The text decoration

required_version

Minimum required ipywidgets version in which the current widget class is supported.

Super classes

HasTraits -> Widget -> DescriptionStyle -> StringStyle -> TextStyle

Public fields

_model_name

Name of the Javascript model in the frontend

required_version

Minimum required ipywidgets version in which the current widget class is supported.

Super classes

HasTraits -> Widget -> DescriptionStyle -> StringStyle -> HTMLStyle

Public fields

_model_name

Name of the Javascript model in the frontend

required_version

Minimum required ipywidgets version in which the current widget class is supported.

Super classes

HasTraits -> Widget -> DescriptionStyle -> StringStyle -> HTMLMathStyle

Public fields

_model_name

Name of the Javascript model in the frontend

required_version

Minimum required ipywidgets version in which the current widget class is supported.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget

Public fields

_model_name

Name of the Javascript model in the frontend

value

A unicode vector

placeholder

A placeholder character

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget -> HTML

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend

style

The HTML style, an object of class "HTMLStyleClass"

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget -> HTMLMath

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend

style

The HTMLMath style, an object of class "HTMLMathStyleClass"

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget -> Label

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend

style

The Label style, an object of class "LabelStyleClass"

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget -> Textarea

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend

disabled

A logical value, whether the slider is disabled

continuous_update

A logical value, whether values should be updated as the slider is moved by the user

rows

An integer, the number of rows

style

The Text style, an object of class "TextStyleClass"

Methods

Inherited methods


Textarea$on_submit()

Add or remove a handler for submit events.

Usage

Textarea$on_submit(handler, remove = FALSE)

Arguments

handler

A function that is called when content is submitted by the user hitting 'enter'.

remove

Logical value, whether the handler is to be removed


Textarea$clone()

The objects of this class are cloneable with this method.

Usage

Textarea$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget -> TextWidget

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend

disabled

A logical value, whether the slider is disabled

continuous_update

A logical value, whether values should be updated as the slider is moved by the user

style

The Text style, an object of class "TextStyleClass"

Methods

Inherited methods


TextWidget$clear()

Clear the text area

Usage

TextWidget$clear()


TextWidget$on_submit()

Add or remove a handler for submit events.

Usage

TextWidget$on_submit(handler, remove = FALSE)

Arguments

handler

A function that is called when content is submitted by the user hitting 'enter'.

remove

Logical value, whether the handler is to be removed


TextWidget$clone()

The objects of this class are cloneable with this method.

Usage

TextWidget$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget -> TextWidget -> PasswordWidget

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> StringWidget -> TextWidget -> Combobox

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend

options

A unicode vector, the available options

ensure_option

A boolean (logical) value, whether at least one option has to be activated