Skip to contents

Classes and constructors to great tag input widgets

Usage

TagsInput(...)

ColorsInput(...)

FloatsInput(...)

IntsInput(...)

Arguments

...

Arguments passed to the inializer

Functions

  • TagsInput(): A taginput constructor

  • ColorsInput(): A color taginput constructor

  • FloatsInput(): A color taginput constructor

  • IntsInput(): A color taginput constructor

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> TagsInputBase

Public fields

_model_name

Name of the Javascript model in the frontend

value

A list of tags

placeholder

A placeholder string

allowed_tags

Optional list with allowed tags.

allow_duplicates

Logical, whether duplicate tags are allowed.

required_version

Minimum required ipywidgets version in which the current widget class is supported.

Methods

Inherited methods


TagsInputBase$validate_value()

Check value for validity,

Usage

TagsInputBase$validate_value(value)

Arguments

value

A character string with one or more tags.


TagsInputBase$new()

Initializer function

Usage

TagsInputBase$new(...)

Arguments

...

Arguments passed to the superclass initializer


TagsInputBase$clone()

The objects of this class are cloneable with this method.

Usage

TagsInputBase$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> TagsInputBase -> TagsInput

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend.

value

A list of tags as unicode strings

tag_style

The string that describes the tag style

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> TagsInputBase -> ColorsInput

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend.

value

A list of tags as unicode strings

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> TagsInputBase -> TagsInput -> ColorsInput

Public fields

_model_name

Name of the Javascript model in the frontend

min

A Float traitlet, the minimum allowed value.

max

A Float traitlet, the maximum allowed value.

value

A list of numeric tags

Methods

Inherited methods


ColorsInput$validate_value()

Check value for validity,

Usage

ColorsInput$validate_value(value)

Arguments

value

A character string with one or more tags.


ColorsInput$new()

Initializer function

Usage

ColorsInput$new(...)

Arguments

...

Arguments passed to the superclass initializer

value

An initial value


ColorsInput$clone()

The objects of this class are cloneable with this method.

Usage

ColorsInput$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> TagsInputBase -> TagsInput -> ColorsInput -> FloatsInput

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend.

value

A list of numeric tags

format

The number format

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> TagsInputBase -> TagsInput -> ColorsInput -> IntsInput

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend.

min

A Integer traitlet, the minimum allowed value.

max

A Integer traitlet, the maximum allowed value.

value

A list of interger number tags

format

The number format