Skip to contents

An R6 class and constructor function for time picker widgets

Usage

TimePicker(...)

Arguments

...

Arguments passed to the inializer

Functions

  • TimePicker(): A constructor for dat picker widgets

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> TimePicker

Public fields

_model_name

Name of the Javascript model in the frontend

_view_name

Name of the Javascript view in the frontend

value

The date and time. If non-zero length, must have valid timezone info.

disabled

Boolean, whether the user can make changes

min

Minimum selectable date and time. If non-zero length, must have valid timezone info.

max

Maximum selectable date and time. If non-zero length, must have valid timezone info.

Methods

Inherited methods


TimePicker$validate_value()

Check wether "value" is within range.

Usage

TimePicker$validate_value(value)

Arguments

value

A date and time to be checked for validity


TimePicker$validate_min()

Validate the "min" field after assignment.

Usage

TimePicker$validate_min(min)

Arguments

min

A minimum date and time to be checked for validity


TimePicker$validate_max()

Validate the "max" field after assignment.

Usage

TimePicker$validate_max(max)

Arguments

max

A maximum date and time to be checked for validity


TimePicker$new()

Usage

TimePicker$new(...)

Arguments

...

Arguments passed to the superclass initializer


TimePicker$clone()

The objects of this class are cloneable with this method.

Usage

TimePicker$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.