A Unicode String Vector Trait
Arguments
- x
A Unicode traitlet
- ...
Other arguments, ignored.
Super class
Trait -> Unicode
Public fields
coerce
Logical value, whether values should be coerced to character strings.
length
Length of the unicode character vector
value
The value of the unicode character vector
optional
A logical value, whether value can be empty.
Methods
Inherited methods
Unicode$validator()
A validator function
Arguments
value
The value to be assigned
Unicode$new()
Initialize an object
Arguments
initial
An initial value
coerce
Logical value, whether values should be coerced to character stringes
optional
Logical value, whether the value may be empty
length
Integer, the intended length of the unicode vector
Unicode$clone()
The objects of this class are cloneable with this method.
Usage
Unicode$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.