Skip to contents

A base class for widgets that are connected with values

Super classes

HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget

Public fields

value

A list or any other vector of values

Methods

Inherited methods


ValueWidget$new()

A generic initializer function

Usage

ValueWidget$new(value, ...)

Arguments

value

A value to initialize instance with

...

Any other arguments, ignored.


ValueWidget$on_change()

Add handler function to be called when value is changed

Usage

ValueWidget$on_change(handler, remove = FALSE)

Arguments

handler

A handler function

remove

A logical value, whether the handler should be removed or added.


ValueWidget$clone()

The objects of this class are cloneable with this method.

Usage

ValueWidget$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.