A class and a constructor function to create generic vector trait(let)s.
Arguments
- ...
Arguments that are passed to the initialize method of 'VectorClass'
Super class
Trait -> Vector
Public fields
value
A list
class
A character string, the common class of the vector elements
Methods
Inherited methods
Vector$validator()
A function that checks the validity of an assigned value,
i.e. whether the assigned value is a list with all elements of the same class
Arguments
value
A value to be assigned as the traitlet value
Vector$new()
Arguments
class
String, optional common class
...
Arguments passed to the superclass initializer
Vector$clone()
The objects of this class are cloneable with this method.
Usage
Vector$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.