Skip to contents

An R6 class and a constructor function for the creation of a link widget, which links two widgets so that their values are synchronized

Usage

WidgetLink(source, target, ...)

DirectionalLink(source, target, ...)

Arguments

source

A link with two elements, the first is a widget, the second is one of its traits.

target

A link with two elements, the first is a widget, the second is one of its traits.

...

Other arguments passed to the inializer

Details

The function WidgetLink creates objects of the R6 Class "WidgetLinkClass", which in turn have the S3 class attribute "WidgetLink"

Functions

  • WidgetLink(): The WidgetLink constructor function

  • DirectionalLink(): The WidgetLink constructor function

Super classes

HasTraits -> Widget -> CoreWidget -> WidgetLink

Public fields

_model_name

Name of the Javascript model in the frontend.

source

A pair of Unicode strings, the first is the JSON representation of a widget, the second is the name of a trait(let) of the widget.

target

A pair of Unicode strings, the first is the JSON representation of a widget, the second is the name of a trait(let) of the widget.

Methods

Inherited methods


An initializer method

Usage

WidgetLink$new(source, target, ...)

Arguments

source

A list with two elements, a widget and the name of a trait(let).

target

A list with two elements, a widget and the name of a trait(let).

...

Futher arguments, passed to the superclass initializer.


The objects of this class are cloneable with this method.

Usage

WidgetLink$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Super classes

HasTraits -> Widget -> CoreWidget -> WidgetLink -> DirectionalLink

Public fields

_model_name

Name of the Javascript model in the frontend.