An R6 class and a constructor function for the creation of widgets that can be used to manipulate floating pairs of point numbers that are bounded within an interval, where a pair defines a number range.
Details
The function BoundedFloatRangeWidget creates objects of the R6
Class "BoundedFloatRangeWidgetClass", which in turn have the S3 class
attribute "BoundedFloatRangeWidget"
Super classes
HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> BoundedFloatRangeWidget
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()ValueWidget$on_change()
BoundedFloatRangeWidget$new()
Usage
BoundedFloatRangeWidget$new(...)