A class and constructor function to create color picker widgets
Super classes
HasTraits -> Widget -> DOMWidget -> DescriptionWidget -> ValueWidget -> ColorPicker
Public fields
_model_nameName of the Javascript model in the frontend
_view_nameName of the Javascript model view in the frontend
conciseBoolean, whether the a short version should be shown
disabledBoolean, whether the button is disabled
valueUnicode string, the color value
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()ValueWidget$initialize()ValueWidget$on_change()