A class and constructor of datetime traitlets.
Arguments
- ...
Arguments that are passed to the initialize method of 'TimeClass'
Super class
Trait -> DatetimeClass
Public fields
value
A date.
coerce
Logical value, whether assignments to the value field should
be coerced to the appropriate type.
Methods
Inherited methods
DatetimeClass$validator()
Check the value assigned to the traitlet.
Usage
DatetimeClass$validator(value)
Arguments
value
The value assigned to the traitlet.
DatetimeClass$new()
Initialize the traitlet.
Arguments
initial
An optional POSIXct object or an object coercive into such an object
coerce
An optional logical value
DatetimeClass$clone()
The objects of this class are cloneable with this method.
Usage
DatetimeClass$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.