A class and a constructor function to create integer vector trait(let)s.
Usage
Integer(...)
# S3 method for class 'Integer'
as.integer(x, ...)
# S3 method for class 'Integer'
as.numeric(x, ...)
# S3 method for class 'Integer'
to_json(x, ...)Super class
Trait -> Integer
Public fields
valueAn integer vector.
optionalLogical value, whether a length-zero value is allowed.
coerceLogical value, whether assignments to the value field should be coerced to the appropriate type.
lengthInteger number, the length the value should have.
Methods
Inherited methods
Integer$new()
Initialize the traitlet.
Arguments
initialAn integer vector, the initial value for the traitlet.
coercecoerce Logical value, whether assignments to the value field should be coerced to the appropriate type.
optionalLogical value, whether a length-zero value is allowed.
lengthInteger number, the length the value should have.