A class and a constructor function to create list trait(let)s.
Arguments
- ...
Arguments that are passed to the initialize method of 'ListClass'
Super class
Trait -> List
Methods
Inherited methods
List$validator()
A function that checks the validity of an assigned value,
i.e. whether the assigned value is a list
Arguments
value
A value to be assigned as the traitlet value
List$clone()
The objects of this class are cloneable with this method.
Arguments
deep
Whether to make a deep clone.