Classes and constructors to wrap output created by code
Usage
OutputWidget(append_output = FALSE, ...)
# S3 method for class 'OutputWidget'
with(data, expr, envir = list(), enclos = parent.frame(), clear = TRUE, ...)Arguments
- append_output
Logical value, whether new output is appended to existing output in the widget or the output is overwritten
- ...
Other arguments, ignored.
- data
An "OutputWidget" object
- expr
An expression to evaluate, or a sequence of expression, encapsulated by curly braces.
- envir
An environment or a list within which `expr` is evaluated.
- enclos
An enclosing environment.
- clear
A logical value, whether clear the output before evaluating `expr`
Public fields
_view_nameName of the Javascript model view in the frontend
_model_nameName of the Javascript model in the frontend
_view_moduleName of the module where the view is defined
_model_moduleName of the Javascript module with the model
_view_module_versionVersion of the module where the view is defined
_model_module_versionVersion of the module where the model is defined
msg_idUnicode string with the id of the last message sent to the frontend.
outputsA list with output strings
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()
OutputWidget$new()
Initializing function
Usage
OutputWidget$new(append_output = TRUE, graphics = FALSE, ...)OutputWidget$display()
A variant of display for output within a display widget.
Arguments
...Arguments passed to the function
display_data.