A Base Class for Traits that are R6 Objects
Super class
Trait -> R6Trait
Public fields
value
An R6 object
class
The R6 class of value
Methods
Inherited methods
R6Trait$validator()
Checks wether value has the corret class
Arguments
value
A value about to be assigned to the trait.
R6Trait$new()
Initialize an object
Arguments
Class
Class of the object
...
Values used for initialization
R6Trait$clone()
The objects of this class are cloneable with this method.
Usage
R6Trait$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.