Classes and constructor functions for tab and accordion widgets
Functions
Accordion(): The constructor function for accordion widgets.Tab(): The construction function for accordion widgets.Stack(): The construction function for accordion widgets.
Public fields
_titlesA dictionary of strings, for internal use only
titlesA dictionary of strings, exposed since ipywidgets 8.
selected_indexAn integer, the field currently selected.
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$notify_children_displayed()
Public fields
_model_nameName of the Javascript model in the frontend.
_view_nameName of the Javascript view in the frontend.
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$notify_children_displayed()Box$get_title()Box$initialize()Box$set_title()Box$validate_index()
Public fields
_model_nameName of the Javascript model in the frontend.
_view_nameName of the Javascript view in the frontend.
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$notify_children_displayed()Box$get_title()Box$initialize()Box$set_title()Box$validate_index()
Public fields
_model_nameName of the Javascript model in the frontend.
_view_nameName of the Javascript view in the frontend.
required_versionMinimum required ipywidgets version in which the current widget class is supported.
Methods
Inherited methods
HasTraits$notify()HasTraits$observe()HasTraits$validate()Widget$_send()Widget$check_version()Widget$close()Widget$display_data()Widget$get_state()Widget$handle_buffers()Widget$handle_comm_msg()Widget$handle_comm_opened()Widget$handle_custom_msg()Widget$handle_displayed()Widget$handle_event()Widget$on_displayed()Widget$on_event()Widget$on_msg()Widget$open()Widget$send()Widget$send_state()Widget$set_state()DOMWidget$add_class()DOMWidget$has_class()DOMWidget$remove_class()Box$notify_children_displayed()Box$get_title()Box$initialize()Box$set_title()Box$validate_index()