An Enumerated Strings Trait
Public fields
enum
a character vector
optional
A logical value, whether value can be empty.
Methods
Inherited methods
StrEnum$validator()
Check whether the assigned vector is one of the allowed enumerated strings.
Arguments
value
A value to be assigned to the trait
StrEnum$new()
Initialize the trait.
Arguments
enum
A character vector of permitted enumerated strings.
default
The default value
optional
Logical can the value be empty?
StrEnum$clone()
The objects of this class are cloneable with this method.
Usage
StrEnum$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.